package com.fjhx.config.mybatis;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import org.apache.ibatis.reflection.MetaObject;

import java.util.Date;

/**
 * 自定义sql字段填充器，自动填充创建修改相关字段
 */
public class CustomMetaObjectHandler implements MetaObjectHandler {

    private static final String CREATE_TIME = "createTime";

    private static final String UPDATE_TIME = "updateTime";

    /**
     * 新增模块时，需要添加的字段
     */
    @Override
    public void insertFill(MetaObject metaObject) {
        Date date = new Date();
        if (ObjectUtil.isNotEmpty(metaObject.hasSetter(CREATE_TIME))) {
            setFieldValByName(CREATE_TIME, date, metaObject);
        }
        if (ObjectUtil.isNotEmpty(metaObject.hasSetter(UPDATE_TIME))) {
            setFieldValByName(UPDATE_TIME, date, metaObject);
        }
    }

    /**
     * 编辑模块时，需要添加的字段
     */
    @Override
    public void updateFill(MetaObject metaObject) {
        if (ObjectUtil.isNotEmpty(metaObject.hasSetter(UPDATE_TIME))) {
            setFieldValByName(UPDATE_TIME, new Date(), metaObject);
        }
    }


}
