package com.fjhx.utils;

import cn.hutool.core.thread.ThreadUtil;
import com.fjhx.config.exception.EmailEngineException;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class RetryUtil {

    /**
     * 任务发生异常开启重试
     *
     * @param runnable 任务
     * @param maxCount 最大重试次数
     * @param sleep    重试间隔
     * @param <T>      返回值类型
     * @return runnable执行结果
     */
    public static <T> T executeT(RetryRunnable<T> runnable, int maxCount, Long sleep) {
        return executeT(runnable, 0, maxCount, sleep);
    }

    private static <T> T executeT(RetryRunnable<T> runnable, int executeCount, int maxCount, Long sleep) {
        try {
            return runnable.run();
        } catch (EmailEngineException e) {
            if (executeCount >= maxCount) {
                throw e;
            }
            log.warn("任务执行失败，已失败{}次，最多允许失败{}次，{}秒后开始重试", executeCount + 1, maxCount, sleep / 1000, e);
            ThreadUtil.sleep(sleep);
            return executeT(runnable, ++executeCount, maxCount, sleep);
        }
    }


    public static void execute(Runnable runnable, int maxCount, Long sleep) {
        execute(runnable, 0, maxCount, sleep);
    }

    private static void execute(Runnable runnable, int executeCount, int maxCount, Long sleep) {
        try {
            runnable.run();
        } catch (EmailEngineException e) {
            if (executeCount >= maxCount) {
                throw e;
            }
            log.warn("任务执行失败，已失败{}次，最多允许失败{}次，{}秒后开始重试", executeCount + 1, maxCount, sleep / 1000, e);
            ThreadUtil.sleep(sleep);
            execute(runnable, ++executeCount, maxCount, sleep);
        }
    }

    public interface RetryRunnable<T> {
        T run();
    }

}
